| Title: | Tibble View: Graphical Display For Data Frame Output |
|---|---|
| Description: | Overrides the print method for data frames and tibbles to provide a graphical output for rectangular data. |
| Authors: | Kirill Müller [aut, cre] (ORCID: <https://orcid.org/0000-0002-1416-3412>), Christoph Sax [aut], cynkra GmbH [fnd] |
| Maintainer: | Kirill Müller <[email protected]> |
| License: | GPL-3 |
| Version: | 0.0-0 |
| Built: | 2026-05-24 07:14:51 UTC |
| Source: | https://github.com/cynkra/tv |
Turn TV on and off
on(verbose = FALSE, port = NULL) off(verbose = FALSE)on(verbose = FALSE, port = NULL) off(verbose = FALSE)
verbose |
talk to the user |
port |
port number, if |
## Not run: tv::on() iris tv::off() ## End(Not run)## Not run: tv::on() iris tv::off() ## End(Not run)
TRUE: on, 'FALSE: off. Exported for debugging.
status()status()